@@ -6,7 +6,7 @@
 * @package language
 * @version $Id: $
 * @copyright (c) 2012 phpBB Group
-* @author 2012-01-04 - Vilius Šumskas
+* @author 2012-09-06 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -324,7 +324,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'	=> 'Nežinoma',
 	'INACTIVE_USERS'	=> 'Neaktyvūs vartotojai',
 	'INACTIVE_USERS_EXPLAIN'	=> 'Čia yra užsiregistravusių bet neaktyvių vartotojų sąrašas. Jeigu norite, galite įjungti, ištrinti arba priminti (el. laišku) šiems vartotojams apie tai.',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Paskutinių 10 užsiregistravusių bet neaktyvių vartotojų. Pilną sąrašą rasite paspaudę ant nuorodos žemiau, kur galėsite įjungti, ištrinti arba priminti (el. laišku) šiems vartotojams apie tai.',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Paskutinių 10 užsiregistravusių bet neaktyvių vartotojų. Vartotojai gali būti neaktyvus dėl to, kad įjungtas vartotojų patvirtinimas ir šie vartotojai nepatvirtino savo vartotojo vardo, arba dėl to, kad jie paprasčiausiai buvo išjungti. Pilną sąrašą rasite paspaudę ant nuorodos žemiau, kur galėsite įjungti, ištrinti arba priminti (el. laišku) šiems vartotojams apie tai.',
 	'NO_INACTIVE_USERS'	=> 'Neaktyvių vartotojų nėra',
 	'SORT_INACTIVE'	=> 'Neaktyvumo datą',
 	'SORT_LAST_VISIT'	=> 'Paskutinį apsilankymą',
