@@ -6,7 +6,7 @@
 * @package language
 * @version $Id: $
 * @copyright (c) 2012 phpBB Group
-* @author 2012-01-04 - Vilius Šumskas
+* @author 2012-09-07 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -181,7 +181,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'	=> 'Jūsų siunčiama forma nebegalioja. Bandykite užpildyti ją dar kartą.',
 	'FORUM'	=> 'Forumas',
 	'FORUMS'	=> 'Forumai',
-	'FORUMS_MARKED'	=> 'Pasirinkti forumai pažymėti kaip perskaityti.',
+	'FORUMS_MARKED'	=> 'Forumai pažymėti kaip perskaityti.',
 	'FORUM_CAT'	=> 'Forumo kategorija',
 	'FORUM_INDEX'	=> 'Pagrindinis diskusijų puslapis',
 	'FORUM_LINK'	=> 'Forumo nuoroda',
@@ -428,6 +428,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'	=> 'Pranešimo datą',
 	'POST_TOPIC'	=> 'Naujos temos kūrimas',
 	'POST_UNAPPROVED'	=> 'Šis pranešimas laukia patvirtinimo',
+	'POWERED_BY'	=> 'Veikia ant %s',
 	'PREVIEW'	=> 'Peržiūrėti',
 	'PREVIOUS'	=> 'Ankstesnis',
 	'PREVIOUS_STEP'	=> 'Atgal',
@@ -436,6 +437,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'	=> 'Asmeninės žinutės',
 	'PRIVATE_MESSAGING'	=> 'Asmeninės žinutės',
 	'PROFILE'	=> 'Vartotojo valdymo pultas',
+	'RANK'	=> 'Rangas',
 	'READING_FORUM'	=> 'Peržiūri temas forume %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Skaito labai svarbų pranešimą',
 	'READING_LINK'	=> 'Lankosi forumo nuorodoje %s',
