@@ -6,7 +6,7 @@
 * @package language
 * @version $Id: $
 * @copyright (c) 2012 phpBB Group
-* @author 2012-01-04 - Vilius Šumskas
+* @author 2012-09-07 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -338,7 +338,7 @@ $help = array(
 	),
 	array(
 		0	=> 'Kodėl diskusijose nėra galimybės X?',
-		1	=> 'Šį produktą sukūrė ir licencijavo phpBB Grupė. Jeigu tikrai manote kad diskusijų lentoje trūksta kokios nors galimybės, apsilankykite phpbb.com puslapyje. Nerašykite apie tai phpbb.com diskusijų lentoje, nes phpBB Grupė tam dalykui naudoja sourceforge.net. Taip pat prieš ką nors ten rašydami, patikrinkite ar tokios galimybės jau nepasiūlė kas nors kitas.',
+		1	=> 'Šį produktą sukūrė ir licencijavo phpBB Grupė. Jeigu tikrai manote, kad diskusijų lentoje trūksta kokios nors galimybės, arba jeigu norite pranešti apie klaidą, apsilankykite phpBB <a href="http://area51.phpbb.com">Atea51</a> puslapyje, kur rasite visus tam reikalingus resursus.',
 	),
 	array(
 		0	=> 'Su kuo turėčiau susisiekti dėl įžeidžiančios informacijos šioje diskusijų lentoje?',
