@@ -6,7 +6,7 @@
 * @package language
 * @version $Id: $
 * @copyright (c) 2012 phpBB Group
-* @author 2012-01-04 - Vilius Šumskas
+* @author 2012-09-07 - Vilius Šumskas
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -129,7 +129,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'	=> 'Sukurti katalogą…',
 	'CURRENT_IMAGE'	=> 'Dabartinis paveikslėlis',
 	'CURRENT_PASSWORD'	=> 'Dabartinis slaptažodis',
-	'CURRENT_PASSWORD_EXPLAIN'	=> 'Jeigu norite pakeisti savo slaptažodį, vartotojo vardą, arba el. pašto adresą, turite įrašyti dabartinį slaptažodį.',
+	'CURRENT_PASSWORD_EXPLAIN'	=> 'Jeigu norite pakeisti savo el. pašto adresą arba vartotojo vardą, turite įrašyti dabartinį slaptažodį.',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN'	=> 'Jeigu norite pakeisti savo slaptažodį, el. pašto adresą, arba vartotojo vardą, turite įrašyti dabartinį slaptažodį.',
 	'CUR_PASSWORD_EMPTY'	=> 'Jūs neįrašėte dabartinio slaptažodžio.',
 	'CUR_PASSWORD_ERROR'	=> 'Slaptažodis, kurį įrašėte, yra neteisingas.',
 	'CUSTOM_DATEFORMAT'	=> 'Individualus…',
@@ -364,6 +365,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'	=> 'Taisyklė sėkmingai sukurta.',
 	'RULE_ALREADY_DEFINED'	=> 'Tokia taisyklė jau egzistuoja.',
 	'RULE_DELETED'	=> 'Taisyklė sėkmingai ištrinta.',
+	'RULE_LIMIT_REACHED'	=> 'Jūs negalite pridėti daugiau asmeninių žinučių taisyklių. Pasiekėte maksimalų taisyklių skaičių.',
 	'RULE_NOT_DEFINED'	=> 'Taisyklė aprašyta neteisingai.',
 	'RULE_REMOVED_MESSAGE'	=> 'Asmeninė žinutė buvo ištrinta, nes atitiko vieną iš nustatytų taisyklių.',
 	'RULE_REMOVED_MESSAGES'	=> '%d asmeninės žinutės buvo ištrintos, nes atitiko vieną iš nustatytų taisyklių.',
